@@ -205,7 +205,7 @@ VariableStringListEditor::VariableStringListEditor(VariableStringListItem *item,
 
     connect(m_comboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VariableStringListEditor::valueChanged);
     connect(m_comboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VariableStringListEditor::activateItem);
-    connect(m_comboBox, QOverload<const QString &>::of(&QComboBox::currentIndexChanged), this, &VariableStringListEditor::setItemValue);
+    connect(m_comboBox, &QComboBox::currentTextChanged, this, &VariableStringListEditor::setItemValue);
 }
 
 void VariableStringListEditor::setItemValue(const QString &newValue)
@@ -309,6 +309,7 @@ VariableRemoveSpacesEditor::VariableRemoveSpacesEditor(VariableRemoveSpacesItem
     m_comboBox->addItem(i18nc("value for variable remove-trailing-spaces", "none"));
     m_comboBox->addItem(i18nc("value for variable remove-trailing-spaces", "modified"));
     m_comboBox->addItem(i18nc("value for variable remove-trailing-spaces", "all"));
+    m_comboBox->addItem(i18nc("value for variable remove-trailing-spaces", "cursor"));
     m_comboBox->setCurrentIndex(item->value());
     l->addWidget(m_comboBox, 0, 2, Qt::AlignLeft);
 
@@ -317,8 +318,8 @@ VariableRemoveSpacesEditor::VariableRemoveSpacesEditor(VariableRemoveSpacesItem
     connect(m_comboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VariableRemoveSpacesEditor::setItemValue);
 }
 
-void VariableRemoveSpacesEditor::setItemValue(int enabled)
+void VariableRemoveSpacesEditor::setItemValue(int removeMode)
 {
-    static_cast<VariableRemoveSpacesItem *>(item())->setValue(enabled == 0);
+    static_cast<VariableRemoveSpacesItem *>(item())->setValue(removeMode);
 }
 // END VariableRemoveSpacesEditor
